
<img src="logo/soothsayer_square.png" width=200>

_________________________________

#### Current Version:
*v2020.07.28*

#### Citation:
*Espinoza, *Dupont et al. 2020 (In Review)

#### Contact:
Josh L. Espinoza: [jespinoz@jcvi.org](jespinoz@jcvi.org).

_________________________________

#### *Soothsayer* Ecosystem:
* [soothsayer_utils](https://github.com/jolespin/soothsayer_utils) - Utility functions for *Soothsayer*
* [hive_networkx](https://github.com/jolespin/hive_networkx) - High-level Hive plot (Martin Krzywinski et al. 2012) implementations using *Matplotlib* in Python. Built on top of *NetworkX* and *Pandas*.
* [compositional](https://github.com/jolespin/compositional) - Compositional data analysis in Python.

_________________________________

#### Case studies, tutorials and usage:
Documentation coming soon. .. ... ..... ........

* [Antimicrobial resistance modeling](tutorials/Notebooks/antimicrobial_resistance_modeling.md)
* [Feature selection using *Clairvoyance* on the Iris dataset with 1000 noise attributes](tutorials/Notebooks/markdown_versions/Denoising_Iris-plus-Noise_with_Clairvoyance/Denoising_Iris-plus-Noise_with_Clairvoyance.md)

_________________________________

#### Installation:
**Please refer to the [installation manual](install/README.md) for installation details.**  
It will make the installation process *much easier* due to all of the Python and R dependencies. 

* pip: [https://pypi.org/project/soothsayer](https://pypi.org/project/soothsayer)

_________________________________


#### Development:
*Soothsayer* is in a developmental stage.  If you're not sure if your installation is a developmental version, check by running: `import soothsayer as sy; print(sy.__developmental__)`.  It is *highly recommended* to [update to the current version](https://github.com/jolespin/soothsayer/tree/master/install#update-to-the-current-release-recommended). 

If you are interested in requesting features or wish to report a bug, please post a GitHub issue prefixed with the tag `[Feature Request]` and `[Bug]`, respectively.

_________________________________



<img src ="https://allpistuff.com/wp-content/uploads/2018/07/twitter.c0030826.jpg" width=100> <img src="logo/soothsayer_wide.png" width=200>


